"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sinon_1 = __importDefault(require("sinon"));
const uuid_1 = require("uuid");
const vitest_1 = require("vitest");
const pipeline_js_1 = require("../internal/pipeline.js");
const register_js_1 = require("../internal/register.js");
const testConfigs = {
    registered: true,
    grpcClient: {
        getAttachCommandsByService: () => ({
            active: [],
            paused: [],
        }),
    },
    sessionId: (0, uuid_1.v4)(),
    streamdalUrl: "localhost:8082",
    streamdalToken: "1234",
    serviceName: "test-service",
    pipelineTimeout: "100",
    stepTimeout: "10",
    dryRun: false,
    audiences: [],
};
const testAudience = {
    serviceName: "test-service",
    componentName: "kafka",
    operationType: 1,
    operationName: "kafka-consumer",
};
const testPipeline = {
    id: "7a04056d-52ae-467e-ab43-2a82a2c90284",
    name: "test-pipeline",
    steps: [
        {
            name: "test-step",
            onSuccess: [],
            onFailure: [],
            step: {
                oneofKind: "detective",
                detective: { args: [], type: 1013, path: "object.field" },
            },
        },
    ],
    NotificationConfigs: [],
};
const testAttachCommand = {
    command: {
        oneofKind: "attachPipeline",
        attachPipeline: {
            pipeline: testPipeline,
        },
    },
    audience: testAudience,
};
const testDetachCommand = {
    command: {
        oneofKind: "detachPipeline",
        detachPipeline: {
            pipelineId: testPipeline.id,
        },
    },
    audience: testAudience,
};
const testPauseCommand = {
    command: {
        oneofKind: "pausePipeline",
        pausePipeline: {
            pipelineId: testPipeline.id,
        },
    },
    audience: testAudience,
};
const testResumeCommand = {
    command: {
        oneofKind: "resumePipeline",
        resumePipeline: {
            pipelineId: testPipeline.id,
        },
    },
    audience: testAudience,
};
const testAttachCommandByServiceResponse = {
    response: {
        active: [testAttachCommand],
        paused: [],
        wasmModules: { test: { id: "test", bytes: new Uint8Array() } },
    },
};
(0, vitest_1.describe)("pipeline tests", () => {
    const key = (0, register_js_1.audienceKey)(testAudience);
    (0, vitest_1.it)("initPipelines should add a given pipeline to internal store and set pipelineInitialized ", async () => {
        sinon_1.default
            .stub(testConfigs.grpcClient, "getAttachCommandsByService")
            .resolves(testAttachCommandByServiceResponse);
        await (0, pipeline_js_1.initPipelines)(testConfigs);
        (0, vitest_1.expect)(register_js_1.internal.pipelines.has(key)).toEqual(true);
        (0, vitest_1.expect)(register_js_1.internal.pipelineInitialized).toEqual(true);
    });
    (0, vitest_1.describe)("processResponse", () => {
        (0, vitest_1.it)("attach command should add pipeline to internal store", async () => {
            await (0, pipeline_js_1.processResponse)(testAttachCommand);
            (0, vitest_1.expect)(register_js_1.internal.pipelines.has(key)).toEqual(true);
            const pipelines = register_js_1.internal.pipelines.get(key);
            (0, vitest_1.expect)(pipelines?.has(testPipeline.id)).toEqual(true);
        });
        (0, vitest_1.it)("detach command should remove pipeline from internal store", async () => {
            register_js_1.internal.pipelines.set(key, new Map([[testPipeline.id, testPipeline]]));
            await (0, pipeline_js_1.processResponse)(testDetachCommand);
            (0, vitest_1.expect)(register_js_1.internal.pipelines.get(key)?.has(testPipeline.id)).toEqual(false);
        });
        (0, vitest_1.it)("pause command should flag pipeline as paused in internal store", async () => {
            register_js_1.internal.pipelines.set(key, new Map([[testPipeline.id, { ...testPipeline, paused: false }]]));
            await (0, pipeline_js_1.processResponse)(testPauseCommand);
            (0, vitest_1.expect)(register_js_1.internal.pipelines.get(key)?.get(testPipeline.id)?.paused).toEqual(true);
        });
        (0, vitest_1.it)("resume command should flag pipeline as not paused in internal store", async () => {
            register_js_1.internal.pipelines.set(key, new Map([[testPipeline.id, { ...testPipeline, paused: true }]]));
            await (0, pipeline_js_1.processResponse)(testResumeCommand);
            (0, vitest_1.expect)(register_js_1.internal.pipelines.get(key)?.get(testPipeline.id)?.paused).toEqual(false);
        });
    });
});
//# sourceMappingURL=pipeline.test.js.map